@@ -171,6 +171,8 @@ which are replaced by the given information:
         'face mhc-tmp-day-face)
     (?/ (if mhc-tmp-first "/" " ")
         'face mhc-tmp-day-face)
+    (?- (if mhc-tmp-first "-" " ")
+        'face mhc-tmp-day-face)
     (?S " " 'face mhc-tmp-day-face)
     (?M (mhc-summary/line-month-string)
         'face mhc-tmp-day-face)
@@ -182,7 +184,8 @@ which are replaced by the given information:
             (make-string 5 ? )
           (format "%02d:%02d" (/ mhc-tmp-begin 60) (% mhc-tmp-begin 60)))
         'face 'mhc-summary-face-time)
-    (?e (if (null mhc-tmp-end)
+    (?e (if (or (null mhc-tmp-end)
+                (and mhc-tmp-begin (= mhc-tmp-end mhc-tmp-begin)))
             (make-string 6 ? )
           (format "-%02d:%02d" (/ mhc-tmp-end 60) (% mhc-tmp-end 60)))
         'face 'mhc-summary-face-time)
@@ -498,10 +501,10 @@ If BANNER is set, it is printed on the horizontal line."
 
 
 (defun mhc-summary/line-subject-string ()
-  (if mhc-tmp-private
-      (and mhc-tmp-schedule mhc-summary-string-secret)
-    (or (mhc-schedule-subject mhc-tmp-schedule) "")))
-
+  (if mhc-tmp-schedule
+      (if mhc-tmp-private
+          mhc-summary-string-secret
+        (mhc-schedule-subject-as-string mhc-tmp-schedule))))
 
 (defun mhc-summary/line-location-string ()
   (let ((location (mhc-schedule-location mhc-tmp-schedule)))
@@ -661,20 +664,36 @@ If BANNER is set, it is printed on the horizontal line."
 (defun mhc-summary-buffer-p (&optional buffer)
   (if buffer
       (set-buffer buffer))
-  mhc-summary-buffer-current-date-month)
+  (eq major-mode 'mhc-summary-mode))
 
-(defun mhc-summary-current-date ()
+(defun mhc-summary-current-date (&optional p)
   (when (mhc-summary-buffer-p)
-    (let ((dayinfo (get-text-property (point) 'mhc-dayinfo)))
+    (let* ((pos (or p (point)))
+           (dayinfo (get-text-property pos 'mhc-dayinfo)))
       (or (and dayinfo (mhc-day-date dayinfo))
           (save-excursion
             (end-of-line)
-            (while (and (not (bobp))
+            (while (and (>= pos (point-min))
                         (null dayinfo))
-              (or (setq dayinfo (get-text-property (point) 'mhc-dayinfo))
-                  (forward-char -1)))
+              (or (setq dayinfo (get-text-property pos 'mhc-dayinfo))
+                  (setq pos (- pos 1))))
             (and dayinfo (mhc-day-date dayinfo)))))))
 
+(defun mhc-summary-region-date ()
+  (when (region-active-p)
+    (let* ((p (region-beginning))
+           dayinfo
+           (datelist ()))
+      (progn
+        (while (<= p (region-end))
+          (and (setq dayinfo (mhc-summary-current-date p))
+               (setq datelist (cons dayinfo datelist)))
+          (setq p (next-single-property-change p 'mhc-dayinfo)))
+        (setq datelist (reverse (delete-dups datelist)))
+        (if (< 1 (length datelist))
+             (cons (car datelist) (car (last datelist)))
+          (car datelist))))))
+
 (defvar mhc-summary-buffer-current-date-month nil
   "Indicate summary buffer's month. It is also used by mhc-summary-buffer-p")
 (make-variable-buffer-local 'mhc-summary-buffer-current-date-month)
@@ -782,4 +801,4 @@ If BANNER is set, it is printed on the horizontal line."
 ;; ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 ;; OF THE POSSIBILITY OF SUCH DAMAGE.
 
-;;; mhc-summary.el ends here.
+;;; mhc-summary.el ends here
