@@ -3,7 +3,7 @@
 ;; Description: Message Harmonized Calendaring system.
 ;; Author:  Yoshinari Nomura <nom@quickhack.net>
 ;; Created: 1994-07-04
-;; Version: 1.1.1
+;; Version: 1.2.0
 ;; Keywords: calendar
 ;; URL: http://www.quickhack.net/mhc
 ;; Package-Requires: ((calfw "20150703"))
@@ -190,8 +190,8 @@
    Field names using by MHC.
 
    X-SC-Category:
-   Space-seperated Keywords. You can set default category to scan.
-   You can also indicate keywords by typing '\\[mhc-rescan-month]', '\\[mhc-goto-this-month]', '\\[mhc-goto-month]', '\\[mhc-goto-date]' with C-u.
+   Space-seperated Keywords.  You can set default category to scan.
+   You can also indicate keywords by typing '\\[mhc-rescan-month]', '\\[mhc-goto-this-month]', '\\[mhc-goto-month]', '\\[mhc-goto-date]' with \\[universal-argument].
 "
   (interactive "P")
   (make-local-variable 'mhc-mode)
@@ -371,10 +371,15 @@ If HIDE-PRIVATE, priavate schedules are suppressed."
     (if mhc-default-hide-private-schedules
         (not current-prefix-arg)
       current-prefix-arg)))
-  (mhc-scan-month date
-                  'mhc-mua
-                  mhc-default-category-predicate-sexp
-                  hide-private))
+  (let ((name (if (and (mhc-summary-buffer-p)
+                       (not (string-match
+                             "^[0-9][0-9][0-9][0-9]-[0-9][0-9]$" (buffer-name))))
+                  (buffer-name))))
+    (mhc-scan-month date
+                    'mhc-mua
+                    mhc-default-category-predicate-sexp
+                    hide-private
+                    name)))
 
 (defvar mhc-goto-date-func 'mhc-goto-date-calendar)
                                         ; or mhc-goto-date-summary
@@ -524,21 +529,22 @@ SCOPE is one of:
    ((eq scope 'wide)
     (mhc-date-ww-last (mhc-date++ edge-date) mhc-start-day-of-week)))))
 
-(defun mhc-scan-month (date mailer category-predicate secret)
+(defun mhc-scan-month (date mailer category-predicate secret &optional name)
   "Make summary buffer for a month indicated by DATE.
 DATE can be any date of the target month.
 If MAILER is 'direct, insert scanned result into current buffer.
 CATEGORY-PREDICATE must be a function that can take one mhc-schedule
 argument and return a boolean value indicates opacity of the article.
 If SECRET is non-nil, hide articles those categories are
-listed in ``mhc-category-as-private''."
+listed in ``mhc-category-as-private''.
+If optional NAME is non-nil, created smmary buffer has the name."
   (let* ((from (mhc-date-mm-first date))
          (to (mhc-date-mm-last date))
          (today (mhc-date-now))
          ;; need three months for mini-calendar
          (dayinfo-list (mhc-db-scan (mhc-date-mm-- from) (mhc-date-mm++ to))))
     (unless (eq 'direct mailer)
-      (mhc-summary-generate-buffer date)
+      (mhc-summary-generate-buffer (or name date))
       (setq mhc-summary-buffer-current-date-month
             (mhc-date-mm-first date)))
     (when mhc-use-wide-scope
@@ -614,7 +620,7 @@ Returns t if the importation was succeeded."
        (list (get-buffer (read-buffer "Import buffer: "
                                       (current-buffer))))))
   (let ((draft-buffer (generate-new-buffer mhc-draft-buffer-name))
-        (current-date (or (mhc-summary-current-date) (mhc-calendar-get-date) (mhc-date-now)))
+        (current-date (or (mhc-summary-region-date) (mhc-summary-current-date) (mhc-calendar-get-date) (mhc-date-now)))
         (succeed t)
         msgp date time subject location category recurrence-tag priority alarm)
     (and (called-interactively-p 'interactive)
@@ -629,9 +635,9 @@ Returns t if the importation was succeeded."
           (mhc-header-narrowing
             (setq msgp (or (mhc-header-get-value "from")
                            (mhc-header-get-value "x-sc-subject")))
-            (mhc-header-delete-header
+            (mhc-header-distill-header
              (concat "^\\("
-                     (mhc-regexp-opt mhc-draft-unuse-hdr-list)
+                     (mhc-regexp-opt mhc-draft-import-header-list)
                      "\\)")
              'regexp))
           (mhc-highlight-message)
@@ -808,15 +814,35 @@ the default action of this command is changed to the latter."
     (mhc-window-pop)))
 
 (defun mhc-import-from-region (beg end)
-  "Import a schedule from region BEG END."
+  "Create new schedule draft from region BEG END."
   (interactive "r")
-  (save-restriction
-    (narrow-to-region beg end)
-    (let ((str (buffer-substring beg end)))
-      (mhc-import)
-      (goto-char (point-max))
-      (insert str)
-      (goto-char (point-min)))))
+  (mhc-import-from-string (buffer-substring beg end)))
+
+(defun mhc-import-from-clipboard ()
+  "Create new schedule draft from clipboard text."
+  (interactive)
+  (mhc-import-from-string (current-kill 0)))
+
+(defun mhc-import-from-string (string)
+  "Create new schedule draft from STRING."
+  (with-temp-buffer
+    (yank 1)
+    (goto-char (point-min))
+    (insert "X-SC-Subject: \n"
+            "X-SC-Location: \n"
+            "X-SC-Day: \n"
+            "X-SC-Time: \n"
+            "X-SC-Category: \n"
+            "X-SC-Priority: \n"
+            "X-SC-Recurrence-Tag: \n"
+            "X-SC-Cond: \n"
+            "X-SC-Duration: \n"
+            "X-SC-Alarm: \n"
+            "X-SC-Record-Id: \n"
+            "X-SC-Sequence: 0\n"
+            "\n"
+            string)
+    (mhc-import)))
 
 (defun mhc-delete ()
   "Delete the current schedule."
@@ -871,11 +897,11 @@ the default action of this command is changed to the latter."
                      ("x-sc-time"  . ,time-list)
                      ("x-sc-day" . ,date-list)))))
 
-(defun mhc-reuse-copy ()
+(defun mhc-reuse-copy (&optional filename)
   "Copy current schedule to template."
   (interactive)
-  (let ((file (mhc-summary-filename))
-        (record (mhc-summary-record)))
+  (let* ((file (or filename (mhc-summary-filename)))
+         (record (mhc-parse-file file)))
     (if (and (stringp file) (file-exists-p file))
         (with-temp-buffer
           (mhc-insert-file-contents-as-coding-system
